# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-23 01:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0004_fix004a'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='route',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='member.Route', verbose_name='route'),
        ),
    ]
