# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-09-12 15:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0015_route_client_id_sequence'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='gender',
            field=models.CharField(blank=True, choices=[('F', 'Female'), ('M', 'Male')], default='U', max_length=1, null='True'),
        ),
    ]
