# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-08-03 11:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0004_fix004a'),
    ]

    operations = [
        migrations.AddField(
            model_name='order_item',
            name='component_group',
            field=models.CharField(choices=[('main_dish', 'Main Dish'), ('dessert', 'Dessert'), ('diabetic', 'Diabetic Dessert'), ('fruit_salad', 'Fruit Salad'), ('green_salad', 'Green Salad'), ('pudding', 'Pudding'), ('compote', 'Compote')], max_length=100, null=True, verbose_name='component group'),
        ),
    ]
