# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-28 18:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0030_route_deliveryhistory'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client_option',
            name='client',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='member.Client', verbose_name='client'),
        ),
        migrations.AlterField(
            model_name='client_option',
            name='option',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='member.Option', verbose_name='option'),
        ),
    ]
