# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-11-25 20:55
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0020_auto_20161122_0458'),
    ]

    operations = [
        migrations.AlterField(
            model_name='address',
            name='postal_code',
            field=models.CharField(max_length=7, verbose_name='postal code'),
        ),
    ]
