# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-03-05 15:33
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0036_member_addresses'),
    ]

    operations = [
        migrations.AlterField(
            model_name='member',
            name='address',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.SET_NULL, to='member.Address', verbose_name='address'),
        ),
    ]
