# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-01 20:07
from __future__ import unicode_literals

import annoying.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0032_relationship'),
    ]

    operations = [
        migrations.AlterField(
            model_name='relationship',
            name='extra_fields',
            field=annoying.fields.JSONField(blank=True, default={}),
        ),
        migrations.AlterField(
            model_name='relationship',
            name='remark',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='relationship',
            name='type',
            field=annoying.fields.JSONField(blank=True, default=[]),
        ),
    ]
