# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-01-10 19:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0024_auto_20161227_1819'),
    ]

    operations = [
        migrations.AddField(
            model_name='route',
            name='vehicle',
            field=models.CharField(choices=[('cycling', 'Cycling'), ('walking', 'Walking'), ('driving', 'Driving')], default='cycling', max_length=20, verbose_name='default vehicle'),
        ),
    ]
