# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-23 01:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0003_auto_20160615_1504'),
    ]

    operations = [
        migrations.AddField(
            model_name='order_item',
            name='free_quantity',
            field=models.IntegerField(null=True, verbose_name='free quantity'),
        ),
        migrations.AddField(
            model_name='order_item',
            name='total_quantity',
            field=models.IntegerField(null=True, verbose_name='total quantity'),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('O', 'Ordered'), ('D', 'Delivered'), ('B', 'Billed'), ('P', 'Paid')], max_length=1, verbose_name='order status'),
        ),
    ]
