# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-01-15 04:19
from __future__ import unicode_literals

from django.db import migrations, models


def set_initial_priorities(apps, schema_editor):
    # set NotePriority initial
    NotePriority = apps.get_model('note', 'NotePriority')
    NotePriority.objects.create(name="Normal")
    NotePriority.objects.create(name="Urgent")


class Migration(migrations.Migration):

    dependencies = [
        ('note', '0003_auto_20160819_2037'),
    ]

    operations = [
        migrations.CreateModel(
            name='NotePriority',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150, verbose_name='Name')),
            ],
            options={
                'ordering': ('name',), 'verbose_name_plural': 'Note priorities'
            },
        ),
        migrations.RunPython(set_initial_priorities),
    ]
