# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-15 21:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0002_auto_20160605_1609'),
    ]

    operations = [
        migrations.CreateModel(
            name='Route',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50, verbose_name='name')),
                ('description', models.TextField(blank=True, null=True, verbose_name='description')),
            ],
            options={
                'verbose_name_plural': 'Routes',
            },
        ),
        migrations.AlterField(
            model_name='client',
            name='birthdate',
            field=models.DateField(blank=True, default=django.utils.timezone.now, null=True),
        ),
        migrations.AlterField(
            model_name='client',
            name='gender',
            field=models.CharField(blank=True, choices=[('', 'Gender'), ('F', 'Female'), ('M', 'Male')], default='U', max_length=1, null=True),
        ),
        migrations.AddField(
            model_name='client',
            name='route',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='member.Route', verbose_name='route'),
        ),
    ]
